package main

import (
	"encoding/binary"
	"fmt"
	"net"
	"time"

	"golang.org/x/text/encoding/korean"
)

func main() {
	listener, err := net.Listen("tcp", ":12345")
	if err != nil {
		fmt.Println("Error starting server:", err)
		return
	}
	defer listener.Close()

	fmt.Println("Mock server listening on :12345")

	for {
		conn, err := listener.Accept()
		if err != nil {
			fmt.Println("Error accepting connection:", err)
			continue
		}
		go handleConnection(conn)
	}
}

func handleConnection(conn net.Conn) {
	defer conn.Close()
	for {
		// 테스트 데이터 생성
		testData := createTestData()

		_, err := conn.Write(testData)
		if err != nil {
			fmt.Println("Error sending data:", err)
			return
		}

		time.Sleep(10 * time.Second) // 10초마다 데이터 전송
	}
}

func createTestData() []byte {
	data := make([]byte, 64)

	// Log_size
	data[0] = 64

	// Log_type
	data[1] = 1

	// Log_datetime (2024-07-01 15:30:00)
	binary.LittleEndian.PutUint16(data[2:4], 2024)
	data[4] = 7  // month
	data[5] = 1  // day
	data[6] = 15 // hour
	data[7] = 30 // minute
	data[8] = 0  // second

	// Log_On
	data[9] = 1

	// Log_Address
	copy(data[10:17], []byte("A1B2C3D"))

	// Log_Area (EUC-KR 인코딩)
	area := "소방서 1"
	areaEncoded, _ := korean.EUCKR.NewEncoder().Bytes([]byte(area))
	copy(data[17:41], areaEncoded)

	// Log_Device (EUC-KR 인코딩)
	device := "연기감지기"
	deviceEncoded, _ := korean.EUCKR.NewEncoder().Bytes([]byte(device))
	copy(data[41:], deviceEncoded)

	return data
}
